@@ -3,7 +3,7 @@ BORIS CLI
 
 Behavioral Observation Research Interactive Software Command Line Interface
 
-Copyright 2012-2022 Olivier Friard
+Copyright 2012-2023 Olivier Friard
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -51,47 +51,51 @@ def all_observations(pj):
 
 commands_list = ["check_state_events", "export_events", "irr", "subtitles", "check_project_integrity", "plot_events"]
 commands_usage = {
-    "check_state_events": ("usage:\nboris_cli -p PROJECT_FILE -o OBSERVATION_ID --command check_state_events\n"
-                           "where\n"
-                           "PROJECT_FILE is the path of the BORIS project\n"
-                           "OBSERVATION_ID is the id of observation(s) (if ommitted all observations are checked)"),
-    "export_events": ("usage:\nboris_cli -p PROJECT_FILE -o OBSERVATION_ID --command export_events [OUTPUT_FORMAT]\n"
-                      "where:\n"
-                      "PROJECT_FILE is the path of the BORIS project\n"
-                      "OBSERVATION_ID is the id of observation(s) (if ommitted all observations are exported)\n"
-                      "OUTPUT_FORMAT can be tsv (default), csv, xls, xlsx, ods, html"),
+    "check_state_events": (
+        "usage:\nboris_cli -p PROJECT_FILE -o OBSERVATION_ID --command check_state_events\n"
+        "where\n"
+        "PROJECT_FILE is the path of the BORIS project\n"
+        "OBSERVATION_ID is the id of observation(s) (if ommitted all observations are checked)"
+    ),
+    "export_events": (
+        "usage:\nboris_cli -p PROJECT_FILE -o OBSERVATION_ID --command export_events [OUTPUT_FORMAT]\n"
+        "where:\n"
+        "PROJECT_FILE is the path of the BORIS project\n"
+        "OBSERVATION_ID is the id of observation(s) (if ommitted all observations are exported)\n"
+        "OUTPUT_FORMAT can be tsv (default), csv, xls, xlsx, ods, html"
+    ),
     "irr": (
         'usage:\nboris_cli -p PROJECT_FILE -o "OBSERVATION_ID1" "OBSERVATION_ID2" --command irr [INTERVAL] [INCLUDE_MODIFIERS]\n'
-        'where:\n'
-        'PROJECT_FILE is the path of the BORIS project\n'
-        'INTERVAL in seconds (default is 1)\n'
-        'INCLUDE_MODIFIERS must be true or false (default is true)'),
-    "subtitles": ('usage:\nboris_cli -p PROJECT_FILE -o "OBSERVATION_ID" --command subtitles [OUTPUT_DIRECTORY]\n'
-                  'where:\n'
-                  'OUTPUT_DIRECTORY is the directory where subtitles files will be saved'),
-    "check_project_integrity":
-        "usage:\nboris_cli -p PROJECT_FILE --command check_project_integrity",
-    "plot_events": ("usage:\nboris_cli - p PROJECT_FILE -o OBSERVATION_ID --command plot_events "
-                    "[OUTPUT_DIRECTORY] [INCLUDE_MODIFIERS] [EXCLUDE_BEHAVIORS] [PLOT_FORMAT]\n"
-                    "where\n"
-                    "OUTPUT_DIRECTORY is the directory where the plots will be saved\n"
-                    "INCLUDE_MODIFIERS must be true or false (default is true)\n"
-                    "EXCLUDE_BEHAVIORS: True: behaviors without events are not plotted (default is true)\n"
-                    "PLOT_FORMAT can be png, svg, pdf, ps")
+        "where:\n"
+        "PROJECT_FILE is the path of the BORIS project\n"
+        "INTERVAL in seconds (default is 1)\n"
+        "INCLUDE_MODIFIERS must be true or false (default is true)"
+    ),
+    "subtitles": (
+        'usage:\nboris_cli -p PROJECT_FILE -o "OBSERVATION_ID" --command subtitles [OUTPUT_DIRECTORY]\n'
+        "where:\n"
+        "OUTPUT_DIRECTORY is the directory where subtitles files will be saved"
+    ),
+    "check_project_integrity": "usage:\nboris_cli -p PROJECT_FILE --command check_project_integrity",
+    "plot_events": (
+        "usage:\nboris_cli - p PROJECT_FILE -o OBSERVATION_ID --command plot_events "
+        "[OUTPUT_DIRECTORY] [INCLUDE_MODIFIERS] [EXCLUDE_BEHAVIORS] [PLOT_FORMAT]\n"
+        "where\n"
+        "OUTPUT_DIRECTORY is the directory where the plots will be saved\n"
+        "INCLUDE_MODIFIERS must be true or false (default is true)\n"
+        "EXCLUDE_BEHAVIORS: True: behaviors without events are not plotted (default is true)\n"
+        "PLOT_FORMAT can be png, svg, pdf, ps"
+    ),
 }
 
 parser = argparse.ArgumentParser(description="BORIS CLI")
-parser.add_argument("-v", "--version", action="store_true", dest='version', help='BORIS version')
-parser.add_argument("-p", "--project", action="store", dest='project_file', help='Project file path')
-parser.add_argument("-o",
-                    "--observation",
-                    nargs="*",
-                    action="store",
-                    default=[],
-                    dest='observation_id',
-                    help='Observation id')
-parser.add_argument("-i", "--info", action="store_true", dest='project_info', help='Project information')
-parser.add_argument("-c", "--command", nargs="*", action="store", dest='command', help='Command to execute')
+parser.add_argument("-v", "--version", action="store_true", dest="version", help="BORIS version")
+parser.add_argument("-p", "--project", action="store", dest="project_file", help="Project file path")
+parser.add_argument(
+    "-o", "--observation", nargs="*", action="store", default=[], dest="observation_id", help="Observation id"
+)
+parser.add_argument("-i", "--info", action="store_true", dest="project_info", help="Project information")
+parser.add_argument("-c", "--command", nargs="*", action="store", dest="command", help="Command to execute")
 
 args = parser.parse_args()
 
@@ -126,7 +130,7 @@ if args.project_file:
 
 if args.observation_id:
     observations_id_list = args.observation_id
-    '''
+    """
     if not args.command:
         print("\nObservations:")
         for observation_id in observations_id_list:
@@ -135,7 +139,7 @@ if args.observation_id:
             else:
                 print("{}: NOT FOUND in project".format(observation_id))
         print()
-    '''
+    """
 
 if args.project_info:
     if not args.command:
@@ -149,17 +153,20 @@ if args.project_info:
                 print("Ethogram\n========")
                 print("Number of behaviors in ethogram: {}".format(len(pj[ETHOGRAM])))
                 for idx in utilities.sorted_keys(pj[ETHOGRAM]):
-                    print("Code: {}\tDescription: {}\tType: {}".format(pj[ETHOGRAM][idx][BEHAVIOR_CODE],
-                                                                       pj[ETHOGRAM][idx]["description"],
-                                                                       pj[ETHOGRAM][idx][TYPE]))
-                '''print("Behaviors: {}".format(",".join([pj[ETHOGRAM][k]["code"] for k in utilities.sorted_keys(pj[ETHOGRAM])])))'''
+                    print(
+                        "Code: {}\tDescription: {}\tType: {}".format(
+                            pj[ETHOGRAM][idx][BEHAVIOR_CODE], pj[ETHOGRAM][idx]["description"], pj[ETHOGRAM][idx][TYPE]
+                        )
+                    )
+                """print("Behaviors: {}".format(",".join([pj[ETHOGRAM][k]["code"] for k in utilities.sorted_keys(pj[ETHOGRAM])])))"""
                 print()
 
                 print("Subjects\n========")
                 print("Number of subjects: {}".format(len(pj[SUBJECTS])))
                 for idx in utilities.sorted_keys(pj[SUBJECTS]):
-                    print("Name: {}\tDescription: {}".format(pj[SUBJECTS][idx]["name"],
-                                                             pj[SUBJECTS][idx]["description"]))
+                    print(
+                        "Name: {}\tDescription: {}".format(pj[SUBJECTS][idx]["name"], pj[SUBJECTS][idx]["description"])
+                    )
                 print()
 
                 print("Observations\n============")
@@ -197,8 +204,9 @@ if args.command:
             observations_id_list = all_observations(pj)
 
         for observation_id in observations_id_list:
-            ret, msg = project_functions.check_state_events_obs(observation_id, pj[ETHOGRAM],
-                                                                pj[OBSERVATIONS][observation_id], HHMMSS)
+            ret, msg = project_functions.check_state_events_obs(
+                observation_id, pj[ETHOGRAM], pj[OBSERVATIONS][observation_id], HHMMSS
+            )
             print("{}: {}".format(observation_id, cleanhtml(msg)))
         sys.exit()
 
@@ -216,12 +224,14 @@ if args.command:
             output_format = args.command[1]
 
         for observation_id in observations_id_list:
-            ok, msg = export_observation.export_events({
-                "selected subjects": subjects,
-                "selected behaviors": behaviors
-            }, observation_id, pj[OBSERVATIONS][observation_id], pj[ETHOGRAM],
-                                                       utilities.safeFileName(observation_id + "." + output_format),
-                                                       output_format)
+            ok, msg = export_observation.export_events(
+                {"selected subjects": subjects, "selected behaviors": behaviors},
+                observation_id,
+                pj[OBSERVATIONS][observation_id],
+                pj[ETHOGRAM],
+                utilities.safeFileName(observation_id + "." + output_format),
+                output_format,
+            )
             if not ok:
                 print(msg)
 
@@ -251,11 +261,15 @@ if args.command:
         if len(args.command) > 2:
             include_modifiers = "TRUE" in args.command[2].upper()
 
-        K, out = irr.cohen_kappa(cursor, observations_id_list[0], observations_id_list[1], interval, subjects,
-                                 include_modifiers)
+        K, out = irr.cohen_kappa(
+            cursor, observations_id_list[0], observations_id_list[1], interval, subjects, include_modifiers
+        )
 
-        print(("Cohen's Kappa - Index of Inter-Rater Reliability\n\n"
-               "Interval time: {interval:.3f} s\n").format(interval=interval))
+        print(
+            ("Cohen's Kappa - Index of Inter-Rater Reliability\n\n" "Interval time: {interval:.3f} s\n").format(
+                interval=interval
+            )
+        )
 
         print(out)
         sys.exit()
@@ -276,11 +290,12 @@ if args.command:
                 print("{} is not a valid directory".format(export_dir))
                 sys.exit()
 
-        ok, msg = project_functions.create_subtitles(pj, observations_id_list, {
-            "selected subjects": subjects,
-            "selected behaviors": behaviors,
-            "include modifiers": True
-        }, export_dir)
+        ok, msg = project_functions.create_subtitles(
+            pj,
+            observations_id_list,
+            {"selected subjects": subjects, "selected behaviors": behaviors, "include modifiers": True},
+            export_dir,
+        )
         if not ok:
             print(cleanhtml(msg))
         sys.exit()
@@ -321,19 +336,22 @@ if args.command:
         if len(args.command) > 4:
             plot_format = args.command[4].lower()
 
-        plot_events.create_events_plot(pj,
-                                       observations_id_list, {
-                                           "selected subjects": subjects,
-                                           "selected behaviors": behaviors,
-                                           "include modifiers": include_modifiers,
-                                           "exclude behaviors": exclude_behaviors,
-                                           "time": TIME_FULL_OBS,
-                                           "start time": 0,
-                                           "end time": 0
-                                       },
-                                       plot_colors=BEHAVIORS_PLOT_COLORS,
-                                       plot_directory=export_dir,
-                                       file_format=plot_format)
+        plot_events.create_events_plot(
+            pj,
+            observations_id_list,
+            {
+                "selected subjects": subjects,
+                "selected behaviors": behaviors,
+                "include modifiers": include_modifiers,
+                "exclude behaviors": exclude_behaviors,
+                "time": TIME_FULL_OBS,
+                "start time": 0,
+                "end time": 0,
+            },
+            plot_colors=BEHAVIORS_PLOT_COLORS,
+            plot_directory=export_dir,
+            file_format=plot_format,
+        )
         sys.exit()
 
     print("Command {} not found!".format(args.command[0]))
