@@ -40,6 +40,7 @@ from . import (
     media_file,
     observation_operations,
     preferences,
+    project_import_export,
     project_server,
     synthetic_time_budget,
     time_budget_widget,
@@ -47,6 +48,7 @@ from . import (
     video_equalizer,
     video_operations,
     project_functions,
+    external_processes,
 )
 
 from . import state_events as state_events
@@ -65,6 +67,7 @@ def connections(self):
     self.actionCheck_project.triggered.connect(self.check_project_integrity)
     self.actionSave_project.triggered.connect(self.save_project_activated)
     self.actionSave_project_as.triggered.connect(self.save_project_as_activated)
+    self.actionExport_project.triggered.connect(lambda: project_import_export.export_project_as_pickle_object(self.pj))
     self.actionClose_project.triggered.connect(self.close_project)
 
     self.action_media_file_and_images_directories_relative_path.triggered.connect(
@@ -192,8 +195,9 @@ def connections(self):
     self.actionAdd_image_overlay_on_video.triggered.connect(lambda: image_overlay.add_image_overlay(self))
     self.actionRemove_image_overlay.triggered.connect(lambda: image_overlay.remove_image_overlay(self))
 
-    self.actionRecode_resize_video.triggered.connect(lambda: self.ffmpeg_process("reencode_resize"))
-    self.actionRotate_video.triggered.connect(lambda: self.ffmpeg_process("rotate"))
+    self.actionRecode_resize_video.triggered.connect(lambda: external_processes.ffmpeg_process(self, "reencode_resize"))
+    self.actionRotate_video.triggered.connect(lambda: external_processes.ffmpeg_process(self, "rotate"))
+    self.actionMerge_media_files.triggered.connect(lambda: external_processes.ffmpeg_process(self, "merge"))
     self.actionMedia_file_information_2.triggered.connect(lambda: media_file.get_info(self))
 
     self.actionCreate_transitions_flow_diagram.triggered.connect(transitions.transitions_dot_script)
