@@ -5,14 +5,24 @@ widget to edit duration > 24 h or < 0
 https://stackoverflow.com/questions/44380202/creating-a-custom-widget-in-pyqt5
 """
 
-import decimal as dc
+import decimal as dec
 
-from PyQt5.QtWidgets import *
-from PyQt5.QtCore import *
+from PyQt5.QtWidgets import (
+    QWidget,
+    QHBoxLayout,
+    QPushButton,
+    QSpinBox,
+    QLabel,
+    QSpacerItem,
+    QSizePolicy,
+    QDoubleSpinBox,
+    QStackedWidget,
+    QRadioButton,
+)
 
-HHMMSS = "hh:mm:ss"
-HHMMSSZZZ = "hh:mm:ss.zzz"
-S = "s"
+from PyQt5.QtCore import pyqtSignal
+
+from . import config as cfg
 
 
 class Widget_hhmmss(QWidget):
@@ -43,9 +53,7 @@ class Widget_hhmmss(QWidget):
         self.minutes.setMinimum(-1)
         self.minutes.setMaximum(60)
         self.minutes.setPrefix("0")
-        self.minutes.valueChanged.connect(
-            lambda value, x=self.minutes: self.value_changed(value, x, 0, 59)
-        )
+        self.minutes.valueChanged.connect(lambda value, x=self.minutes: self.value_changed(value, x, 0, 59))
         lay.addWidget(self.minutes)
         lay.addWidget(QLabel(":"))
 
@@ -53,9 +61,7 @@ class Widget_hhmmss(QWidget):
         self.seconds.setMinimum(-1)
         self.seconds.setMaximum(60)
         self.seconds.setPrefix("0")
-        self.seconds.valueChanged.connect(
-            lambda value, x=self.seconds: self.value_changed(value, x, 0, 59)
-        )
+        self.seconds.valueChanged.connect(lambda value, x=self.seconds: self.value_changed(value, x, 0, 59))
         lay.addWidget(self.seconds)
         lay.addWidget(QLabel(":"))
 
@@ -63,9 +69,7 @@ class Widget_hhmmss(QWidget):
         self.milliseconds.setMinimum(-1)
         self.milliseconds.setMaximum(1000)
         self.milliseconds.setPrefix("00")
-        self.milliseconds.valueChanged.connect(
-            lambda value, x=self.milliseconds: self.value_changed(value, x, 0, 999)
-        )
+        self.milliseconds.valueChanged.connect(lambda value, x=self.milliseconds: self.value_changed(value, x, 0, 999))
         lay.addWidget(self.milliseconds)
 
         spacerItem = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)
@@ -148,10 +152,9 @@ class Widget_seconds(QWidget):
 class Duration_widget(QWidget):
     def __init__(self, time_value=0, parent=None):
 
-        # QWidget.__init__(self, parent=parent)
         super().__init__()
 
-        self.time_value = dc.Decimal(time_value).quantize(dc.Decimal(".001"))
+        self.time_value = dec.Decimal(time_value).quantize(dec.Decimal(".001"))
 
         lay = QHBoxLayout(self)
         lay.setSpacing(0)
@@ -168,7 +171,7 @@ class Duration_widget(QWidget):
 
         lay.addWidget(self.Stack)
 
-        self.format_hhmmss = QRadioButton("hh:mm:ss")
+        self.format_hhmmss = QRadioButton(cfg.HHMMSS)
         self.format_hhmmss.setChecked(True)
         self.format_hhmmss.clicked.connect(self.set_format_hhmmss)
         lay.addWidget(self.format_hhmmss)
@@ -192,15 +195,15 @@ class Duration_widget(QWidget):
 
         self.w1.sign.setText("-" if new_time < 0 else "+")
 
-        h = abs(new_time) // 3600
-        m = (abs(new_time) - h * 3600) // 60
+        h = int(abs(new_time) // 3600)
+        m = int((abs(new_time) - h * 3600) // 60)
         s = int((abs(new_time) - h * 3600 - m * 60))
-        ms = round((abs(new_time) - h * 3600 - m * 60 - s) * 1000, 3)
+        ms = round((abs(new_time) - h * 3600 - m * 60 - s) * 1000)
 
-        self.w1.hours.setValue(int(h))
-        self.w1.minutes.setValue(int(m))
-        self.w1.seconds.setValue(int(s))
-        self.w1.milliseconds.setValue(int(ms))
+        self.w1.hours.setValue(h)
+        self.w1.minutes.setValue(m)
+        self.w1.seconds.setValue(s)
+        self.w1.milliseconds.setValue(ms)
 
         self.w2.seconds2.setValue(new_time)
 
@@ -228,23 +231,13 @@ class Duration_widget(QWidget):
         """
         switch time format in base of time_format value
         """
-        if time_format in [HHMMSS, HHMMSSZZZ]:
+        if time_format in [cfg.HHMMSS, cfg.HHMMSSZZZ]:
             self.set_format_hhmmss()
-        if time_format in [S]:
+        if time_format in [cfg.S]:
             self.set_format_s()
 
-    def get_time(self) -> dc.Decimal:
+    def get_time(self) -> dec.Decimal:
         """
         return time displayed by widget in seconds
         """
-        return dc.Decimal(self.time_value).quantize(dc.Decimal(".001"))
-
-
-"""
-if __name__ == '__main__':
-    import sys
-    app = QApplication(sys.argv)
-    w = Duration_widget()
-    w.show()
-    sys.exit(app.exec_())
-"""
+        return dec.Decimal(self.time_value).quantize(dec.Decimal(".001"))
