@@ -65,7 +65,7 @@ def export_observations_list_clicked(self):
     export the list of observations
     """
 
-    resultStr, selected_observations = select_observations.select_observations(self.pj, cfg.MULTIPLE)
+    resultStr, selected_observations = select_observations.select_observations2(self, cfg.MULTIPLE)
     if not resultStr or not selected_observations:
         return
 
@@ -112,7 +112,7 @@ def observations_list(self):
     if self.playerType in cfg.VIEWERS:
         close_observation(self)
 
-    result, selected_obs = select_observations.select_observations(self.pj, cfg.SINGLE)
+    result, selected_obs = select_observations.select_observations2(self, cfg.SINGLE)
 
     if not selected_obs:
         return
@@ -132,7 +132,6 @@ def observations_list(self):
         QtTest.QTest.qWait(1000)
 
     if result == cfg.OPEN:
-        # select_observations.select_observations(self.pj, cfg.OPEN)
         load_observation(self, selected_obs[0], cfg.OBS_START)
 
     if result == cfg.VIEW:
@@ -176,9 +175,9 @@ def open_observation(self, mode: str) -> str:
             close_observation(self)
     selected_observations = []
     if mode == cfg.OBS_START:
-        _, selected_observations = select_observations.select_observations(self.pj, cfg.OPEN)
+        _, selected_observations = select_observations.select_observations2(self, cfg.OPEN)
     if mode == cfg.VIEW:
-        _, selected_observations = select_observations.select_observations(self.pj, cfg.VIEW)
+        _, selected_observations = select_observations.select_observations2(self, cfg.VIEW)
 
     if selected_observations:
         return load_observation(self, selected_observations[0], mode)
@@ -272,8 +271,8 @@ def edit_observation(self):
         else:
             close_observation(self)
 
-    _, selected_observations = select_observations.select_observations(
-        self.pj, cfg.EDIT, windows_title="Edit observation"
+    _, selected_observations = select_observations.select_observations2(
+        self, cfg.EDIT, windows_title="Edit observation"
     )
 
     if selected_observations:
@@ -285,8 +284,8 @@ def remove_observations(self):
     remove observations from project file
     """
 
-    _, selected_observations = select_observations.select_observations(
-        self.pj, cfg.MULTIPLE, windows_title="Remove observations"
+    _, selected_observations = select_observations.select_observations2(
+        self, cfg.MULTIPLE, windows_title="Remove observations"
     )
     if not selected_observations:
         return
@@ -1239,7 +1238,7 @@ def close_observation(self):
     logging.info(f"Observation {self.playerType} closed")
 
 
-def initialize_new_media_observation(self):
+def initialize_new_media_observation(self) -> bool:
     """
     initialize new observation from media file(s)
     """
@@ -1522,7 +1521,7 @@ def initialize_new_media_observation(self):
         count = 0
         for idx in self.pj[cfg.OBSERVATIONS][self.observationId][cfg.PLOT_DATA]:
             if count == 0:
-
+                data_ok: bool = True
                 data_file_path = project_functions.full_path(
                     self.pj[cfg.OBSERVATIONS][self.observationId][cfg.PLOT_DATA][idx]["file_path"],
                     self.projectFileName,
@@ -1535,7 +1534,8 @@ def initialize_new_media_observation(self):
                             self.pj[cfg.OBSERVATIONS][self.observationId][cfg.PLOT_DATA][idx]["file_path"]
                         ),
                     )
-                    return False
+                    data_ok = False
+                    # return False
 
                 w1 = plot_data_module.Plot_data(
                     data_file_path,
@@ -1561,22 +1561,24 @@ def initialize_new_media_observation(self):
                         ),
                     )
                     del w1
-                    return False
+                    data_ok = False
+                    # return False
 
-                w1.setWindowFlags(Qt.WindowStaysOnTopHint)
-                w1.sendEvent.connect(self.signal_from_widget)  # keypress event
+                if data_ok:
+                    w1.setWindowFlags(Qt.WindowStaysOnTopHint)
+                    w1.sendEvent.connect(self.signal_from_widget)  # keypress event
 
-                w1.show()
+                    w1.show()
 
-                self.ext_data_timer_list.append(QTimer())
-                self.ext_data_timer_list[-1].setInterval(w1.time_out)
-                self.ext_data_timer_list[-1].timeout.connect(lambda: self.timer_plot_data_out(w1))
-                self.timer_plot_data_out(w1)
+                    self.ext_data_timer_list.append(QTimer())
+                    self.ext_data_timer_list[-1].setInterval(w1.time_out)
+                    self.ext_data_timer_list[-1].timeout.connect(lambda: self.timer_plot_data_out(w1))
+                    self.timer_plot_data_out(w1)
 
-                self.plot_data[count] = w1
+                    self.plot_data[count] = w1
 
             if count == 1:
-
+                data_ok: bool = True
                 data_file_path = project_functions.full_path(
                     self.pj[cfg.OBSERVATIONS][self.observationId][cfg.PLOT_DATA][idx]["file_path"],
                     self.projectFileName,
@@ -1589,7 +1591,8 @@ def initialize_new_media_observation(self):
                             self.pj[cfg.OBSERVATIONS][self.observationId][cfg.PLOT_DATA][idx]["file_path"]
                         ),
                     )
-                    return False
+                    data_ok = False
+                    # return False
 
                 w2 = plot_data_module.Plot_data(
                     data_file_path,
@@ -1615,18 +1618,20 @@ def initialize_new_media_observation(self):
                         ),
                     )
                     del w2
-                    return False
+                    data_ok = False
+                    # return False
 
-                w2.setWindowFlags(Qt.WindowStaysOnTopHint)
-                w2.sendEvent.connect(self.signal_from_widget)
+                if data_ok:
+                    w2.setWindowFlags(Qt.WindowStaysOnTopHint)
+                    w2.sendEvent.connect(self.signal_from_widget)
 
-                w2.show()
-                self.ext_data_timer_list.append(QTimer())
-                self.ext_data_timer_list[-1].setInterval(w2.time_out)
-                self.ext_data_timer_list[-1].timeout.connect(lambda: self.timer_plot_data_out(w2))
-                self.timer_plot_data_out(w2)
+                    w2.show()
+                    self.ext_data_timer_list.append(QTimer())
+                    self.ext_data_timer_list[-1].setInterval(w2.time_out)
+                    self.ext_data_timer_list[-1].timeout.connect(lambda: self.timer_plot_data_out(w2))
+                    self.timer_plot_data_out(w2)
 
-                self.plot_data[count] = w2
+                    self.plot_data[count] = w2
 
             count += 1
 
